class ProducerModel:
    def __init__(self, key: any = None, value: any = None, headers: any = None):
        self.__key = key
        self.__value = value
        self.__headers = headers

    @property
    def key(self):
        return self.__key

    @key.setter
    def key(self, key):
        self.__key = key

    @property
    def value(self):
        return self.__value

    @value.setter
    def value(self, value):
        self.__value = value

    @property
    def headers(self):
        return self.__headers

    @headers.setter
    def headers(self, headers):
        self.__headers = headers



from setuptools import setup, find_packages

setup(
    name='kafka_message',
    version='0.2',
    summary="",
    author="hoatv9",
    license='MIT',
    description="Test",
    packages=find_packages(),
    install_requires=[
        'kafka-python'
    ],
)


import json
from kafka import KafkaProducer
# from kafka.errors import KafkaError

from kafka_message.model.producer_model import ProducerModel


class KafkaMessageProducer:
    def __init__(self, bootstrap_servers: str, security_protocol: str, ssl_cafile: str, 
                 sasl_mechanism: str, sasl_plain_username: str, sasl_plain_password: str):
        self.bootstrap_servers = bootstrap_servers
        self.security_protocol = security_protocol
        self.ssl_cafile = ssl_cafile
        self.sasl_mechanism=sasl_mechanism
        self.sasl_plain_username=sasl_plain_username
        self.sasl_plain_password=sasl_plain_password


    def send_message(self, topic: str, model: ProducerModel):
        try:
            producer = KafkaProducer(bootstrap_servers=self.bootstrap_servers,     
                                    security_protocol=self.security_protocol,
                                    ssl_cafile=self.ssl_cafile,
                                    sasl_mechanism=self.sasl_mechanism,
                                    sasl_plain_username=self.sasl_plain_username,
                                    sasl_plain_password=self.sasl_plain_password,

                                    compression_type='gzip', 
                                    value_serializer=lambda v: json.dumps(v).encode('utf-8'),
                                    key_serializer=lambda v: json.dumps(v).encode('utf-8')
                                    )
             
            producer.send(topic, model.value, model.key, model.headers)           

            print(f"Message sent to topic '{topic}'")
            return True, f"Message sent to topic '{topic}'"
        except Exception as e:
            # log.error(e, exc_info=True)
            print(f"Failed to send message to topic '{topic}': {str(e)}")
            return False, f"Failed to send message to topic '{topic}': {str(e)}"
        finally:
            producer.close()
